@@ -17,12 +17,13 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+#include <libgnome/libgnome.h>
 #include <syslog.h>
 #include <signal.h>
 #include <sys/wait.h>
 #include <X11/Xauth.h>
 #include <sys/types.h>
+#include <unistd.h>
 #include <fcntl.h>
 
 #include "gdm.h"
@@ -97,8 +98,14 @@ gdm_display_check_loop (GdmDisplay *disp)
 				       "disabling display %s"), disp->name);
 	  /* only display a dialog box if this is a local display */
 	  if (disp->type == TYPE_LOCAL ||
-	      disp->type == TYPE_FLEXI)
-		  gdm_text_message_dialog (s);
+	      disp->type == TYPE_FLEXI) {
+		  char *ls = g_strdup_printf
+			  (_("Failed to start the display server "
+			     "several times in a short time period; "
+			     "disabling display %s"), disp->name);
+		  gdm_text_message_dialog (ls);
+		  g_free (ls);
+	  }
 	  gdm_error ("%s", s);
 	  g_free (s);
 
@@ -144,12 +151,17 @@ gdm_display_manage (GdmDisplay *d)
 {
     pid_t pid;
     int i;
+    int fds[2];
 
     if (!d) 
 	return FALSE;
 
     gdm_debug ("gdm_display_manage: Managing %s", d->name);
 
+    if (pipe (fds) < 0) {
+	    gdm_error (_("%s: Cannot create pipe"), "gdm_display_manage");
+    }
+
     if ( ! gdm_display_check_loop (d))
 	    return FALSE;
 
@@ -183,9 +195,13 @@ gdm_display_manage (GdmDisplay *d)
 	gdm_connection_close (unixconn);
 	unixconn = NULL;
 
+	closelog ();
+
 	/* Close everything */
-	for (i = 0; i < sysconf (_SC_OPEN_MAX); i++)
-	    close(i);
+	for (i = 0; i < sysconf (_SC_OPEN_MAX); i++) {
+		if (i != fds[0])
+			close(i);
+	}
 
 	/* No error checking here - if it's messed the best response
          * is to ignore & try to continue */
@@ -193,6 +209,10 @@ gdm_display_manage (GdmDisplay *d)
 	open("/dev/null", O_RDWR); /* open stdout - fd 1 */
 	open("/dev/null", O_RDWR); /* open stderr - fd 2 */
 
+	openlog ("gdm", LOG_PID, LOG_DAEMON);
+
+	d->slave_notify_fd = fds[0];
+
 	if (d->type == TYPE_LOCAL) {
 	    gdm_slave_start (d);
 	    /* if we ever return, bad things are happening */
@@ -226,6 +246,8 @@ gdm_display_manage (GdmDisplay *d)
     default:
 	gdm_debug ("gdm_display_manage: Forked slave: %d",
 		   (int)pid);
+	d->master_notify_fd = fds[1];
+	close (fds[0]);
 	break;
     }
 
@@ -289,6 +311,16 @@ gdm_display_dispose (GdmDisplay *d)
 	    gdm_connection_set_close_notify (conn, NULL, NULL);
     }
 
+    if (d->slave_notify_fd >= 0) {
+	    close (d->slave_notify_fd);
+	    d->slave_notify_fd = -1;
+    }
+
+    if (d->master_notify_fd >= 0) {
+	    close (d->master_notify_fd);
+	    d->master_notify_fd = -1;
+    }
+
     displays = g_slist_remove (displays, d);
 
     if (SERVER_IS_FLEXI (d))
