@@ -37,6 +37,7 @@
 
 #include "gdm.h"
 #include "misc.h"
+#include "slave.h"
 
 /* Configuration option variables */
 extern gchar *GdmPidFile;
@@ -49,6 +50,20 @@ extern char **environ;
 extern pid_t extra_process;
 extern int extra_status;
 extern gboolean preserve_ld_vars;
+extern int gdm_in_signal;
+
+static void
+do_syslog (int type, const char *s)
+{
+	if (gdm_in_signal > 0) {
+		char *m = g_strdup_printf (GDM_SOP_SYSLOG " %ld %d %s",
+					   (long)getpid (), type, s);
+		gdm_slave_send (m, FALSE);
+		g_free (m);
+	} else {
+		syslog (type, "%s", s);
+	}
+}
 
 
 /**
@@ -64,14 +79,14 @@ void
 gdm_fail (const gchar *format, ...)
 {
     va_list args;
-    gchar *s;
+    char *s;
 
     va_start (args, format);
     s = g_strdup_vprintf (format, args);
     va_end (args);
 
     /* Log to both syslog and stderr */
-    syslog (LOG_CRIT, "%s", s);
+    do_syslog (LOG_CRIT, s);
     fprintf (stderr, "%s\n", s);
     fflush (stderr);
 
@@ -101,13 +116,13 @@ void
 gdm_info (const gchar *format, ...)
 {
     va_list args;
-    gchar *s;
+    char *s;
 
     va_start (args, format);
     s = g_strdup_vprintf (format, args);
     va_end (args);
-    
-    syslog (LOG_INFO, "%s", s);
+
+    do_syslog (LOG_INFO, s);
     
     g_free (s);
 }
@@ -125,13 +140,13 @@ void
 gdm_error (const gchar *format, ...)
 {
     va_list args;
-    gchar *s;
+    char *s;
 
     va_start (args, format);
     s = g_strdup_vprintf (format, args);
     va_end (args);
-    
-    syslog (LOG_ERR, "%s", s);
+
+    do_syslog (LOG_ERR, s);
     
     g_free (s);
 }
@@ -149,7 +164,7 @@ void
 gdm_debug (const gchar *format, ...)
 {
     va_list args;
-    gchar *s;
+    char *s;
 
     if ( ! GdmDebug) 
 	return;
@@ -158,7 +173,7 @@ gdm_debug (const gchar *format, ...)
     s = g_strdup_vprintf (format, args);
     va_end (args);
 
-    syslog (LOG_ERR, "%s", s);	/* Maybe should be LOG_DEBUG, but then normally
+    do_syslog (LOG_ERR, s);	/* Maybe should be LOG_DEBUG, but then normally
 				 * you wouldn't get it in the log.  ??? */
     
     g_free (s);
@@ -464,6 +479,8 @@ gdm_exec_wait (char * const *argv, gboolean no_display,
 	if (pid == 0) {
 		int i;
 
+		closelog ();
+
 		for (i = 0; i < sysconf (_SC_OPEN_MAX); i++)
 			close (i);
 
@@ -478,6 +495,8 @@ gdm_exec_wait (char * const *argv, gboolean no_display,
 			setegid (getgid ());
 		}
 
+		openlog ("gdm", LOG_PID, LOG_DAEMON);
+
 		if (no_display) {
 			gnome_unsetenv ("DISPLAY");
 			gnome_unsetenv ("XAUTHORITY");
@@ -505,6 +524,9 @@ static sigset_t sigchldblock_mask, sigchldblock_oldmask;
 static int sigterm_blocked = 0;
 static sigset_t sigtermblock_mask, sigtermblock_oldmask;
 
+static int sigusr2_blocked = 0;
+static sigset_t sigusr2block_mask, sigusr2block_oldmask;
+
 void
 gdm_sigchld_block_push (void)
 {
@@ -555,6 +577,30 @@ gdm_sigterm_block_pop (void)
 	}
 }
 
+void
+gdm_sigusr2_block_push (void)
+{
+	sigusr2_blocked ++;
+
+	if (sigusr2_blocked == 1) {
+		/* Set signal mask */
+		sigemptyset (&sigusr2block_mask);
+		sigaddset (&sigusr2block_mask, SIGUSR2);
+		sigprocmask (SIG_BLOCK, &sigusr2block_mask, &sigusr2block_oldmask);
+	}
+}
+
+void
+gdm_sigusr2_block_pop (void)
+{
+	sigusr2_blocked --;
+
+	if (sigusr2_blocked == 0) {
+		/* reset signal mask back */
+		sigprocmask (SIG_SETMASK, &sigusr2block_oldmask, NULL);
+	}
+}
+
 pid_t
 gdm_fork_extra (void)
 {
@@ -781,64 +827,4 @@ gdm_setup_gids (const char *login, gid_t gid)
 	return TRUE;
 }
 
-/* See comment in misc.h file */
-const char *
-gdm_cons_i18n (const char *string)
-{
-	char *vt_is_UTF8;
-	static gboolean checked = FALSE;
-	static gboolean is_utf8 = FALSE;
-	char *cmd;
-
-	if (checked) {
-		if (is_utf8)
-			return _(string);
-		else
-			return string;
-	}
-
-	checked = TRUE;
-	is_utf8 = FALSE;
-
-	if (access (EXPANDED_SBINDIR "/gdmopen", X_OK) != 0)
-		return string;
-
-	vt_is_UTF8 = g_find_program_in_path ("vt-is-UTF8");
-	if (vt_is_UTF8 == NULL) {
-		int i;
-		char *check_paths[] = {
-			"/usr/bin/vt-is-UTF8",
-			"/usr/sbin/vt-is-UTF8",
-			"/bin/vt-is-UTF8",
-			"/sbin/vt-is-UTF8",
-			NULL
-		};
-		for (i = 0;
-		     check_paths[i] != NULL &&
-		     vt_is_UTF8 == NULL;
-		     i++) {
-			if (access (check_paths[i], X_OK) == 0) {
-				vt_is_UTF8 = g_strdup (check_paths[i]);
-			}
-		}
-	}
-
-	if (vt_is_UTF8 == NULL)
-		return string;
-
-	cmd = g_strdup_printf (EXPANDED_SBINDIR "/gdmopen %s -q",
-			       vt_is_UTF8);
-
-	if (system (cmd) == 0)
-		is_utf8 = TRUE;
-
-	g_free (cmd);
-
-	if (is_utf8)
-		return _(string);
-	else
-		return string;
-}
-
-
 /* EOF */
