@@ -57,8 +57,8 @@ gdm_verify_pam_conv (int num_msg, const struct pam_message **msg,
 		     struct pam_response **resp,
 		     void *appdata_ptr)
 {
-    gint replies = 0;
-    gchar *s;
+    int replies = 0;
+    char *s;
     struct pam_response *reply = NULL;
     
     reply = malloc (sizeof (struct pam_response) * num_msg);
@@ -74,12 +74,14 @@ gdm_verify_pam_conv (int num_msg, const struct pam_message **msg,
 	    
 	case PAM_PROMPT_ECHO_ON:
 	    /* PAM requested textual input with echo on */
-	    s = gdm_slave_greeter_ctl (GDM_PROMPT, _((gchar *) msg[replies]->msg));
-	    if (gdm_slave_greeter_check_interruption (s)) {
+	    s = gdm_slave_greeter_ctl (GDM_PROMPT, _(msg[replies]->msg));
+
+	    if (gdm_slave_greeter_check_interruption ()) {
 		    g_free (s);
 		    free (reply);
 		    return PAM_CONV_ERR;
 	    }
+
 	    reply[replies].resp_retcode = PAM_SUCCESS;
 	    reply[replies].resp = strdup (ve_sure_string (s));
 	    g_free (s);
@@ -87,8 +89,8 @@ gdm_verify_pam_conv (int num_msg, const struct pam_message **msg,
 	    
 	case PAM_PROMPT_ECHO_OFF:
 	    /* PAM requested textual input with echo off */
-	    s = gdm_slave_greeter_ctl (GDM_NOECHO, _((gchar *) msg[replies]->msg));
-	    if (gdm_slave_greeter_check_interruption (s)) {
+	    s = gdm_slave_greeter_ctl (GDM_NOECHO, _(msg[replies]->msg));
+	    if (gdm_slave_greeter_check_interruption ()) {
 		    g_free (s);
 		    free (reply);
 		    return PAM_CONV_ERR;
@@ -100,13 +102,13 @@ gdm_verify_pam_conv (int num_msg, const struct pam_message **msg,
 	    
 	case PAM_ERROR_MSG:
 	    /* PAM sent a message that should displayed to the user */
-	    gdm_slave_greeter_ctl_no_ret (GDM_ERRDLG, _((gchar *) msg[replies]->msg));
+	    gdm_slave_greeter_ctl (GDM_ERRDLG, _(msg[replies]->msg));
 	    reply[replies].resp_retcode = PAM_SUCCESS;
 	    reply[replies].resp = NULL;
 	    break;
 	case PAM_TEXT_INFO:
 	    /* PAM sent a message that should displayed to the user */
-	    gdm_slave_greeter_ctl_no_ret (GDM_MSG, _((gchar *) msg[replies]->msg));
+	    gdm_slave_greeter_ctl (GDM_MSG, _(msg[replies]->msg));
 	    reply[replies].resp_retcode = PAM_SUCCESS;
 	    reply[replies].resp = NULL;
 	    break;
@@ -146,14 +148,14 @@ gdm_verify_standalone_pam_conv (int num_msg, const struct pam_message **msg,
 	memset (reply, 0, sizeof (struct pam_response) * num_msg);
 
 	for (replies = 0; replies < num_msg; replies++) {
-
 		switch (msg[replies]->msg_style) {
 
 		case PAM_PROMPT_ECHO_ON:
 			/* PAM requested textual input with echo on */
 			s = gdm_failsafe_question (cur_gdm_disp,
-						   _((gchar *) msg[replies]->msg),
+						   _(msg[replies]->msg),
 						   TRUE /* echo */);
+
 			reply[replies].resp_retcode = PAM_SUCCESS;
 			reply[replies].resp = strdup (ve_sure_string (s));
 			g_free (s);
@@ -162,8 +164,9 @@ gdm_verify_standalone_pam_conv (int num_msg, const struct pam_message **msg,
 		case PAM_PROMPT_ECHO_OFF:
 			/* PAM requested textual input with echo off */
 			s = gdm_failsafe_question (cur_gdm_disp,
-						   _((gchar *) msg[replies]->msg),
+						   _(msg[replies]->msg),
 						   FALSE /* echo */);
+
 			reply[replies].resp_retcode = PAM_SUCCESS;
 			reply[replies].resp = strdup (ve_sure_string (s));
 			g_free (s);
@@ -173,7 +176,7 @@ gdm_verify_standalone_pam_conv (int num_msg, const struct pam_message **msg,
 			/* PAM sent a message that should displayed to the user */
 			gdm_error_box (cur_gdm_disp,
 				       GTK_MESSAGE_ERROR,
-				       _((gchar *) msg[replies]->msg));
+				       _(msg[replies]->msg));
 			reply[replies].resp_retcode = PAM_SUCCESS;
 			reply[replies].resp = NULL;
 			break;
@@ -182,7 +185,7 @@ gdm_verify_standalone_pam_conv (int num_msg, const struct pam_message **msg,
 			/* PAM sent a message that should displayed to the user */
 			gdm_error_box (cur_gdm_disp,
 				       GTK_MESSAGE_INFO,
-				       _((gchar *) msg[replies]->msg));
+				       _(msg[replies]->msg));
 			reply[replies].resp_retcode = PAM_SUCCESS;
 			reply[replies].resp = NULL;
 			break;
@@ -298,7 +301,7 @@ gdm_verify_user (GdmDisplay *d,
 	    gdm_slave_greeter_ctl_no_ret (GDM_MSG, _("Please enter your username"));
 	    login = gdm_slave_greeter_ctl (GDM_LOGIN, _("Username:"));
 	    if (login == NULL ||
-		gdm_slave_greeter_check_interruption (login)) {
+		gdm_slave_greeter_check_interruption ()) {
 		    if (started_timer)
 			    gdm_slave_greeter_ctl_no_ret (GDM_STOPTIMER, "");
 		    g_free (login);
@@ -437,12 +440,11 @@ gdm_verify_user (GdmDisplay *d,
 		     * and password.  That is the most common case but not
 		     * neccessairly true, this message needs to be changed
 		     * to allow for such cases */
-		    auth_errmsg = g_strdup_printf
-			    (_("\nIncorrect username or password. "
-			       "Letters must be typed in the correct case. "  
-			       "Please make sure the Caps Lock key is not enabled."));
+		    auth_errmsg = 
+			    _("\nIncorrect username or password. "
+			      "Letters must be typed in the correct case. "  
+			      "Please make sure the Caps Lock key is not enabled.");
 		    gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX, auth_errmsg);
-		    g_free (auth_errmsg);
 	    } else {
 		    gdm_slave_greeter_ctl_no_ret (GDM_ERRDLG, _("Authentication failed"));
 	    }
@@ -653,7 +655,7 @@ gdm_verify_check (void)
 		openlog ("gdm", LOG_PID, LOG_DAEMON);
 
 		gdm_text_message_dialog
-			(gdm_cons_i18n (N_("Can't find PAM configuration for gdm.")));
+			(_("Can't find PAM configuration for gdm."));
 		gdm_fail ("gdm_verify_check: %s",
 			  _("Can't find PAM configuration for gdm."));
 	}
