@@ -8,6 +8,7 @@ typedef enum _GreeterItemState GreeterItemState;
 typedef enum _GreeterItemType GreeterItemType;
 typedef enum _GreeterItemSizeType GreeterItemSizeType;
 typedef enum _GreeterItemPosType GreeterItemPosType;
+typedef enum _GreeterItemShowModes GreeterItemShowModes;
 
 enum _GreeterItemState {
   GREETER_ITEM_STATE_NORMAL,
@@ -37,6 +38,17 @@ enum _GreeterItemPosType {
   GREETER_ITEM_POS_RELATIVE,
 };
 
+enum _GreeterItemShowModes {
+  GREETER_ITEM_SHOW_EVERYWHERE = 0xffff,
+  GREETER_ITEM_SHOW_NOWHERE = 0,
+  GREETER_ITEM_SHOW_CONSOLE_FIXED = 1<<0,
+  GREETER_ITEM_SHOW_CONSOLE = (1<<0) | (1<<1),
+  GREETER_ITEM_SHOW_CONSOLE_FLEXI = 1<<1,
+  GREETER_ITEM_SHOW_REMOTE_FLEXI = 1<<2,
+  GREETER_ITEM_SHOW_FLEXI = (1<<1) | (1<<2),
+  GREETER_ITEM_SHOW_REMOTE = 1<<3
+};
+
 struct _GreeterItemInfo {
   GreeterItemInfo *parent;
   
@@ -45,6 +57,10 @@ struct _GreeterItemInfo {
   GreeterItemPosType y_type;
   double x;
   double y;
+
+  GreeterItemShowModes show_modes;
+  char *show_type; /* timed, system, config */
+  char *show_subtype; /* halt, suspend, reboot */
   
   GreeterItemSizeType width_type;
   GreeterItemSizeType height_type;
@@ -56,6 +72,9 @@ struct _GreeterItemInfo {
   
   char *id;
 
+  /* Button can propagate states and collect states from underlying items */
+  gboolean button;
+
   GreeterItemType item_type;
 
   char *files[GREETER_ITEM_STATE_MAX];
@@ -85,6 +104,7 @@ struct _GreeterItemInfo {
   
   /* Runtime state: */
   GreeterItemState state;
+  GreeterItemState base_state;
   gboolean mouse_down;
   gboolean mouse_over;
 
@@ -110,4 +130,7 @@ char *greeter_item_expand_text (const char *text);
 
 void greeter_item_update_text (GreeterItemInfo *info);
 
+gboolean greeter_item_is_visible (GreeterItemInfo *info);
+GreeterItemInfo *greeter_item_find_my_button (GreeterItemInfo *info);
+
 #endif /* __GREETER_ITEMS_H__ */
