@@ -23,6 +23,7 @@ static void
 user_pw_activate (GtkEntry *entry, GreeterItemInfo *info)
 {
   static gboolean first_return = TRUE;
+  char *tmp;
   GreeterItemInfo *error_info;
   GreeterItemInfo *message_info;
   
@@ -62,7 +63,10 @@ user_pw_activate (GtkEntry *entry, GreeterItemInfo *info)
   
   entry_is_login = FALSE;
 
-  g_print ("%c%s\n", STX, gtk_entry_get_text (GTK_ENTRY (entry)));
+  tmp = g_locale_from_utf8 (gtk_entry_get_text (GTK_ENTRY (entry)),
+			    -1, NULL, NULL, NULL);
+  g_print ("%c%s\n", STX, tmp);
+  g_free (tmp);
 }
 
 gboolean
@@ -166,11 +170,13 @@ greeter_item_pam_message (const char *message)
 
 
 static gboolean
-error_clear (GreeterItemInfo *error_info)
+error_clear (gpointer data)
 {
-      g_object_set (G_OBJECT (error_info->item),
-		    "text", "",
-		    NULL);
+	GreeterItemInfo *error_info = data;
+
+	g_object_set (G_OBJECT (error_info->item),
+		      "text", "",
+		      NULL);
 
 	err_box_clear_handler = 0;
 	return FALSE;
