@@ -7,6 +7,7 @@
 #include "greeter_item.h"
 
 #include <syslog.h>
+#include <unistd.h>
 
 #include "gdm.h"
 #include "gdmwm.h"
@@ -42,6 +43,24 @@ greeter_suspend_handler (void)
 	}
 }
 
+static void
+greeter_config_handler (GreeterItemInfo *info,
+			gpointer         user_data)
+{
+	/* we should be now fine for focusing new windows */
+	gdm_wm_focus_new_windows (TRUE);
+
+#if 0
+	/* Taken from gdmlogin, does this apply? */
+	/* configure interruption */
+	login_entry = FALSE; /* no matter where we are,
+				this is no longer a login_entry */
+#endif
+	/* configure interruption */
+	g_print ("%c%c%c\n", STX, BEL, GDM_INTERRUPT_CONFIGURE);
+}
+
+
 static void
 greeter_system_handler (GreeterItemInfo *info,
 			gpointer         user_data)
@@ -86,6 +105,7 @@ greeter_system_handler (GreeterItemInfo *info,
 			 GTK_STOCK_OK,
 			 GTK_RESPONSE_OK);
   
+  gtk_widget_show_all (dialog);
   gdm_wm_center_window (GTK_WINDOW (dialog));
 
   gdm_wm_no_login_focus_push ();
@@ -124,4 +144,7 @@ greeter_item_system_setup (void)
   greeter_item_register_action_callback ("system_button",
 					 (ActionFunc)greeter_system_handler,
 					 NULL);
+  greeter_item_register_action_callback ("config_button",
+					 (ActionFunc)greeter_config_handler,
+					 NULL);
 }
