@@ -1,7 +1,7 @@
 /* Misc routines
  *
  * (c) 2000 Eazel, Inc.
- * (c) 2001 George Lebl
+ * (c) 2001,2002 George Lebl
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -141,6 +141,15 @@ ve_vector_len (char * const *v)
 	return i;
 }
 
+gboolean
+ve_bool_equal (gboolean a, gboolean b)
+{
+	if ((a && b) || (!a && !b))
+		return TRUE;
+	else
+		return FALSE;
+}
+
 gboolean
 ve_is_string_in_list (const GList *list, const char *string)
 {
@@ -199,6 +208,18 @@ ve_find_file (const char *filename, const GList *directories)
 		g_free (s);
 	}
 
+	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
+				       filename, TRUE, NULL);
+	if (s != NULL)
+		return s;
+
+	ss = g_build_filename (g_get_prgname (), filename, NULL);
+	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
+				       ss, TRUE, NULL);
+	g_free (ss);
+	if (s != NULL)
+		return s;
+
 	s = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR,
 				       filename, TRUE, NULL);
 	if (s != NULL)
